import time

# Import the preset TestFixture.
from .Frames_trasnmission_fixture import FixtureFramesTrasnmission, ChannelFactory

from xtr import logging, Severity
logger = logging.getLogger(__name__)


# Create the test case class, that inherits from the preset TestFixture.
class TestCanFdtransmitter(FixtureFramesTrasnmission):

    # This method will be executed just before
    # the test case core method execution.
    def setUp(self):
        logger.info("Setup test case")

    # This method will be executed just after
    # the test case core method execution.
    def tearDown(self):
        logger.info("Tear down test case")

    # Create the test case core method that holds the main test steps.
    def test_can_fd_transmitter(self):

        # Define frame properties.
        # The values provided below are arbitrary examples.
        # They do not belong to any actual in vehicle communication.
        channel_name = 'B1_CAN_FD'
        frame_id = 0x17
        payload = [0x1, 0x2, 0x3, 0x4, 0x5, 0x6,
                   0x7, 0x8, 0x9, 0x10, 0x11, 0x12]

        can_fd_ch = ChannelFactory().get_can_channel(channel_name, True)

        # Retrieves the desired can frame object
        # associated with the the frame_id.
        can_fd_fr = can_fd_ch.get_frame(frame_id)

        # Log any useful message.
        logger.info("Transmit a can fd frame")

        # Transmit the can fd frame.
        can_fd_transmit = can_fd_fr.transmitter.transmit_frame(payload)

        time.sleep(2)

        # Confirm the correct transmission by
        # verifying the boolean return value of transmit_frame().
        # If there are no issues during transmission,
        # the return value should be true.
        self.assertTrue(can_fd_transmit, Severity.BLOCKER,
                        "Error when sending a can fd message")
